@@ -1,7 +1,7 @@
 package App::Wubot::Util::WebFetcher;
 use Moose;
 
-our $VERSION = '0.4.2'; # VERSION
+our $VERSION = '0.5.0'; # VERSION
 
 use HTTP::Message;
 use LWP::UserAgent;
@@ -23,7 +23,7 @@ App::Wubot::Util::WebFetcher - fetch content from the web
 
 =head1 VERSION
 
-version 0.4.2
+version 0.5.0
 
 =head1 SYNOPSIS
 
@@ -116,6 +116,28 @@ variable PERL_LWP_SSL_CA_FILE or HTTPS_CA_FILE.
 sub fetch {
     my ( $self, $url, $config ) = @_;
 
+    if ( $config->{curl} ) {
+        my $command = join( " ", $config->{curl}, qq('$url') );
+
+        my $output;
+
+        # run command capturing output
+        open my $run, "-|", "$command 2>&1" or die "Unable to execute curl: $command: $!";
+        while ( my $line = <$run> ) {
+            $output .= $line;
+        }
+        close $run;
+
+        # check exit status
+        unless ( $? eq 0 ) {
+          my $status = $? >> 8;
+          my $signal = $? & 127;
+          die "Error running command:$command\n\tstatus=$status\n\tsignal=$signal\n\n$output";
+        }
+
+        return $output;
+    }
+
     my $ua = new LWP::UserAgent;
 
     if ( $config->{timeout} ) {
@@ -137,10 +159,6 @@ sub fetch {
         $ua->proxy(['https'], $config->{proxy} );
     }
 
-    if ( $config->{socks_proxy} ) {
-        $ua->proxy(['socks'],  $config->{socks_proxy} );
-    }
-
     if ( $config->{ignore_cert_errors} ) {
         $self->logger->debug( "Disabling certificate verification" );
         $ua->ssl_opts( verify_hostname => 0 )
@@ -191,3 +209,23 @@ __PACKAGE__->meta->make_immutable;
 __END__
 
 =back
+
+=head1 SOCKS PROXIES
+
+If you are using a socks proxy, set the 'proxy' to something like
+this:
+
+  socks://localhost:1080/
+
+You can create a compatible socks proxy using ssh:
+
+  ssh -N -D 1080 somehost
+
+You may also need to install:
+
+  LWP::Protocol::socks
+
+If LWP::Protocol::socks is not properly installed, you may see an
+error message such as:
+
+  501 Protocol scheme ''socks'' is not supported.
